// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// 
// Module: DetectorPosition
// Author: Hassan Siddiqui
//
// Description: 
// Describes a position across a CCD detector, in terms of the CCD ID,
// and the position in that CCD.
//  
// Modifications: See ChangeLog
// 
// $Id: DetectorPosition.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef DETECTORPOSITION_H
#define DETECTORPOSITION_H

// General classes
#include <iostream>

// SAS-specific classes

// General utility functions
#include "errstr.h"
#include "Tracer.h"

// Local classes


class DetectorPosition
{
public:
 
  DetectorPosition(int ccdid, int rawx, int rawy):
    _ccdid(ccdid),
    _rawx(rawx),
    _rawy(rawy)
    {}

  int ccdid() const {PROC; RETURN _ccdid;}
  int rawx()  const {PROC; RETURN _rawx;}
  int rawy()  const {PROC; RETURN _rawy;}

private:

  int _ccdid;
  int _rawx;
  int _rawy;

};

// Insertor for DetectorPosition
ostream &operator << (ostream &stream, const DetectorPosition o);

#endif
